==> kkbox_openapi-0.9.5.tar.gz: README.md <==
# KKBOX Open API Dart Developer SDK

[![License Apache](https://img.shields.io/badge/license-Apache-green.svg?style=flat)](https://raw.githubusercontent.com/KKBOX/OpenAPI-Swift/master/LICENSE)&nbsp;

KKBOX's Open API provides various data from KKBOX's rich music
archive. It helps you to access data about KKBOX's song tracks,
albums, artist playlist and so on.

For further information, please visit
[KKBOX Developer Site](https://docs-en.kkbox.codes).

## Installation

To use the SDK, add `kkbox_openapi` to your `pubspec.yaml` file.

Then run `pub get`.

## Usage

A simple usage example:

```dart
import 'package:kkbox_openapi/kkbox_openapi.dart';

main() {
  var clientID = "5fd35360d795498b6ac424fc9cb38fe7";
  var clientSecret = "8bb68d0d1c2b483794ee1a978c9d0b5d";
  var api = new KKBOXOpenAPI(clientID, clientSecret);
  try {
    await api.fetchAccessTokenByClientCredential();
    var result = await api.fetchTrack('4kxvr3wPWkaL9_y3o_');
    print(result);
  } catch (err) {
    print(err);
  }
}
```

## License

Copyright 2018 KKBOX Technologies Limited

```text
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```

==> kkbox_openapi-0.9.7.tar.gz: README.md <==
# KKBOX Open API Dart Developer SDK

[![License Apache](https://img.shields.io/badge/license-Apache-green.svg?style=flat)](https://raw.githubusercontent.com/KKBOX/OpenAPI-Swift/master/LICENSE)&nbsp;

KKBOX's Open API provides various data from KKBOX's rich music archive. It helps
you to access data about KKBOX's song tracks, albums, artist playlist and so on.

For further information, please visit
[KKBOX Developer Site](https://docs-en.kkbox.codes).

## Installation

To use the SDK, add `kkbox_openapi` to your `pubspec.yaml` file.

Then run `pub get`.

## Usage

A simple usage example:

```dart
import 'package:kkbox_openapi/kkbox_openapi.dart';

main() {
  var clientID = "YOUR_CLIENT_ID";
  var clientSecret = "YOUR_CLIENT_SECRET";
  var api = new KKBOXOpenAPI(clientID, clientSecret);
  try {
    await api.fetchAccessTokenByClientCredential();
    var result = await api.fetchTrack('4kxvr3wPWkaL9_y3o_');
    print(result);
  } catch (err) {
    print(err);
  }
}
```

## License

Copyright 2018 KKBOX Technologies Limited

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
